@@ -57,13 +57,11 @@ class CrawlManagerTest(TestCase):
     @patch("shub_workflow.crawl.WorkFlowManager.schedule_spider")
     def test_schedule_spider_dd(self, mocked_super_schedule_spider, mocked_add_job_tags, mocked_get_jobs):
 
-        mocked_add_job_tags.side_effect = [[]]
-
         with script_args(["myspider"]):
             manager = TestManager()
 
         mocked_super_schedule_spider.side_effect = ["999/1/1"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
 
         # first loop: schedule spider
         result = manager.workflow_loop()
@@ -88,13 +86,11 @@ class CrawlManagerTest(TestCase):
     @patch("shub_workflow.crawl.WorkFlowManager.schedule_spider")
     def test_schedule_implicit_spider(self, mocked_super_schedule_spider, mocked_add_job_tags, mocked_get_jobs):
 
-        mocked_add_job_tags.side_effect = [[]]
-
         with script_args([]):
             manager = TestManagerWithSpider()
 
         mocked_super_schedule_spider.side_effect = ["999/1/1"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
 
         # first loop: schedule spider
         result = manager.workflow_loop()
@@ -106,13 +102,11 @@ class CrawlManagerTest(TestCase):
     @patch("shub_workflow.crawl.WorkFlowManager.schedule_spider")
     def test_schedule_spider_bad_outcome(self, mocked_super_schedule_spider, mocked_add_job_tags, mocked_get_jobs):
 
-        mocked_add_job_tags.side_effect = [[]]
-
         with script_args(["myspider"]):
             manager = TestManager()
 
         mocked_super_schedule_spider.side_effect = ["999/1/1"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
 
         # first loop: schedule spider
         result = manager.workflow_loop()
@@ -141,17 +135,18 @@ class CrawlManagerTest(TestCase):
 
         mocked_get_jobs_side_effect = [
             # the resumed job
-            [{"tags": ["FLOW_ID=3a20"], "key": "999/10/1"}],
+            [{"tags": ["FLOW_ID=3a20", "NAME=test", "OTHER=other"], "key": "999/10/1"}],
             # the owned running job
             [{"spider": "myspider", "key": "999/1/1", "tags": ["FLOW_ID=3a20", "PARENT_NAME=test"]}],
             # the owned finished jobs
             [],
         ]
         mocked_get_jobs.side_effect = mocked_get_jobs_side_effect
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
         self.assertTrue(manager.is_resumed)
         self.assertEqual(len(manager._running_job_keys), 1)
         self.assertEqual(manager.get_jobs.call_count, len(mocked_get_jobs_side_effect))
+        mocked_add_job_tags.assert_any_call(tags=['FLOW_ID=3a20', 'NAME=test', 'OTHER=other'])
 
         # first loop: spider still running in workflow. Continue.
         manager.is_finished = lambda x: None
@@ -174,10 +169,10 @@ class CrawlManagerTest(TestCase):
 
         mocked_get_jobs_side_effect = [
             # the not resumed job (different flow id)
-            [{"tags": ["FLOW_ID=3344"], "key": "999/10/1"}],
+            [{"tags": ["FLOW_ID=3344", "NAME=othertest"], "key": "999/10/1"}],
         ]
         mocked_get_jobs.side_effect = mocked_get_jobs_side_effect
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
         self.assertFalse(manager.is_resumed)
         self.assertEqual(len(manager._running_job_keys), 0)
         self.assertEqual(manager.get_jobs.call_count, len(mocked_get_jobs_side_effect))
@@ -197,7 +192,7 @@ class CrawlManagerTest(TestCase):
             # owned finished jobs
             [],
         ]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
         self.assertTrue(manager.is_resumed)
         self.assertEqual(len(manager._running_job_keys), 0)
 
@@ -220,7 +215,7 @@ class CrawlManagerTest(TestCase):
             manager = PeriodicTestManager()
 
         mocked_super_schedule_spider.side_effect = ["999/1/1"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
 
         # first loop: schedule spider
         result = manager.workflow_loop()
@@ -260,7 +255,7 @@ class CrawlManagerTest(TestCase):
             manager = ListTestManager()
 
         mocked_super_schedule_spider.side_effect = ["999/1/1", "999/1/2", "999/1/3", "999/1/4", "999/1/5"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
 
         # first loop: schedule spider with first set of arguments
         result = manager.workflow_loop()
@@ -347,7 +342,7 @@ class CrawlManagerTest(TestCase):
             manager = _ListTestManager()
 
         mocked_super_schedule_spider.side_effect = ["999/1/1", "999/1/2"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
 
         # first loop: schedule spider with first set of arguments
         result = manager.workflow_loop()
@@ -388,7 +383,7 @@ class CrawlManagerTest(TestCase):
             manager = _ListTestManager()
 
         mocked_super_schedule_spider.side_effect = ["999/1/1", "999/1/2"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
 
         # first loop: schedule spider with first set of arguments
         result = manager.workflow_loop()
@@ -427,7 +422,7 @@ class CrawlManagerTest(TestCase):
 
         mocked_get_jobs.side_effect = [
             # the resumed job
-            [{"tags": ["FLOW_ID=3a20"], "key": "999/10/1"}],
+            [{"tags": ["FLOW_ID=3a20", "NAME=test"], "key": "999/10/1"}],
             # running spiders
             [],
             # finished spiders
@@ -441,7 +436,7 @@ class CrawlManagerTest(TestCase):
             ],
         ]
         mocked_super_schedule_spider.side_effect = ["999/2/1"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
         self.assertTrue(manager.is_resumed)
         self.assertEqual(len(manager._running_job_keys), 0)
 
@@ -497,7 +492,7 @@ class CrawlManagerTest(TestCase):
             [],
         ]
         mocked_super_schedule_spider.side_effect = ["999/2/1"]
-        manager._WorkFlowManager__on_start()
+        manager._on_start()
         self.assertTrue(manager.is_resumed)
         self.assertEqual(len(manager._running_job_keys), 1)
 
